pymia
=====

.. image:: https://readthedocs.org/projects/pymia/badge/?version=latest
   :target: http://pymia.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

pymia is an open-source Python (py) package for deep learning-based medical image analysis (mia).
The package addresses two main parts of deep learning pipelines: data handling and evaluation.
The package itself is independent of the deep learning framework used but can easily be integrated into TensorFlow and PyTorch pipelines.
Therefore, pymia is highly flexible, allows for fast prototyping, and reduces the burden of implementing data handling and evaluation.
Founded, actively developed and maintained, by Fabian Balsiger and Alain Jungo.
